package gov.usgs.earthquake.nshmp.netcdf;

import java.io.IOException;
import java.nio.file.Path;

import gov.usgs.earthquake.nshmp.netcdf.reader.NetcdfUtils.Key;

import ucar.nc2.dataset.NetcdfDatasets;

/**
 * Supported NetCDF data types.
 */
public enum NetcdfDataType {

  GROUND_MOTIONS,
  HAZARD_CURVES;

  /**
   * Returns the data type read from a NetCDF file with attribute "dataType".
   *
   * @param netcdfPath Path to NetCDF file
   */
  public static NetcdfDataType getDataType(Path netcdfPath) {
    try (var ncd = NetcdfDatasets.openDataset(netcdfPath.toString())) {
      var group = ncd.getRootGroup();
      var vDataType = group.attributes().findAttribute(Key.DATA_TYPE);
      return NetcdfDataType.valueOf(vDataType.getStringValue());
    } catch (IOException e) {
      throw new RuntimeException("Could not read Netcdf file [" + netcdfPath + " ]");
    }
  }
}
